import 'package:flutter/material.dart';
import 'package:insuideindoor/main/MyHome.dart';
import 'package:insuideindoor/main/poiInfo.dart';
import 'package:insuideindoor/main/poi_model.dart';

class FilterData extends StatefulWidget {
  final String searchData;
  const FilterData({Key? key, required this.searchData}) : super(key: key);

  @override
  State<FilterData> createState() => _FilterDataState();
}

class _FilterDataState extends State<FilterData> {
  @override
  void initState() {
    super.initState();
    myfn();
  }

  myfn() {
    searchList.clear();
    for (int i = 0; i < dataPois.length; i++) {
      Datum d = dataPois[i];

      if (d.category.toString().toLowerCase().contains(widget.searchData) ||
          d.subcategory.toString().toLowerCase().contains(widget.searchData)) {
        searchList.add(d);
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    TextEditingController mySearchController =
        TextEditingController(text: widget.searchData);
    double width = MediaQuery.of(context).size.width;
    double height = MediaQuery.of(context).size.height;
    double btnPadding = 10.0;
    double btnSize = 25.0;
    double fontSize = 16.0;
    return Scaffold(
      body: Container(
          decoration: const BoxDecoration(
              color: Colors.white,
              borderRadius: BorderRadius.all(Radius.circular(16.0))),
          child: ListView.builder(
              padding: EdgeInsets.zero,
              physics: const ClampingScrollPhysics(),
              itemCount: 1,
              itemBuilder: (BuildContext context, int index) {
                return Column(
                  children: [
                    const SizedBox(height: 8),
                    const SizedBox(height: 35),
                    Container(
                      margin: const EdgeInsets.symmetric(horizontal: 20),
                      padding: const EdgeInsets.symmetric(vertical: 0),
                      decoration: BoxDecoration(
                          color: Color(0xffEAEBED),
                          borderRadius: BorderRadius.circular(40)),
                      child: TextFormField(
                        initialValue: widget.searchData,
                        // controller: mySearchController,
                        scrollPadding: EdgeInsets.zero,
                        decoration: InputDecoration(
                          isDense: true,
                          contentPadding: const EdgeInsets.all(0.0),
                          prefixIcon: Icon(Icons.search,
                              size: btnSize, color: Color(0xFF555555)),
                          suffixIcon: Icon(
                            Icons.directions,
                            size: btnSize,
                            color: Color(0xFF555555),
                          ),
                          hintText: "Search",
                          hintStyle: const TextStyle(
                              fontWeight: FontWeight.bold, fontSize: 15),
                          border: OutlineInputBorder(
                              borderRadius: BorderRadius.circular(40),
                              borderSide: BorderSide(color: Color(0xffEAEBED))),
                          disabledBorder: OutlineInputBorder(
                              borderRadius: BorderRadius.circular(40),
                              borderSide: BorderSide(color: Color(0xffEAEBED))),
                          enabledBorder: OutlineInputBorder(
                              borderRadius: BorderRadius.circular(40),
                              borderSide: BorderSide(color: Color(0xffEAEBED))),
                          focusedBorder: OutlineInputBorder(
                              borderRadius: BorderRadius.circular(40),
                              borderSide: BorderSide(color: Color(0xffEAEBED))),
                        ),
                        // onEditingComplete: myfn(),
                        onChanged: (text) {
                          if (text.isNotEmpty) {
                            searchList.clear();
                            for (int i = 0; i < dataPois.length; i++) {
                              Datum d = dataPois[i];

                              if (d.category
                                      .toString()
                                      .toLowerCase()
                                      .contains(text) ||
                                  d.subcategory
                                      .toString()
                                      .toLowerCase()
                                      .contains(text)) {
                                searchList.add(d);
                              }
                            }

                            setState(() {});
                          } else {
                            searchList.clear();

                            setState(() {});
                          }
                        },
                      ),
                    ),
                    Stack(
                      children: [
                        Column(
                          mainAxisSize: MainAxisSize.min,
                          children: const [
                            SizedBox(height: 10),
                          ],
                        ),
                        if (searchList != null && searchList.length > 0)
                          Container(
                            height: height * 0.87,
                            color: Colors.white,
                            child: GestureDetector(
                              onTap: () {
                                Navigator.push(
                                  context,
                                  MaterialPageRoute(
                                      builder: (context) => PoiInfo(
                                            geo: searchList[index]
                                                .lat
                                                .toString(),
                                            poiName: searchList[index]
                                                .poiMultilingual!
                                                .en!
                                                .name
                                                .toString(),
                                            iconImage:
                                                "assets/images/restro2.png",
                                          )),
                                );
                              },
                              child: ListView.builder(
                                  itemCount: searchList.length,
                                  itemBuilder:
                                      (BuildContext context, int index) {
                                    return Container(
                                      padding: EdgeInsets.symmetric(
                                          vertical: 8, horizontal: 10),
                                      child: Column(
                                        children: [
                                          Row(
                                            children: [
                                              Icon(
                                                Icons.supervised_user_circle,
                                                size: 40,
                                              ),
                                              Padding(
                                                padding: const EdgeInsets.only(
                                                    left: 12.0),
                                                child: Column(
                                                  mainAxisSize:
                                                      MainAxisSize.min,
                                                  crossAxisAlignment:
                                                      CrossAxisAlignment.start,
                                                  children: [
                                                    Text(
                                                      "${searchList[index].poiMultilingual!.en!.name}",
                                                      style: TextStyle(
                                                          fontWeight:
                                                              FontWeight.bold),
                                                    ),
                                                    Text(
                                                        "${searchList[index].subcategory}")
                                                  ],
                                                ),
                                              )
                                            ],
                                          ),
                                          Divider(
                                            thickness: 1,
                                          )
                                        ],
                                      ),
                                    );
                                  }),
                            ),
                          ),
                      ],
                    ),
                  ],
                );
              })),
    );
  }
}
